==> neo4j-cypher-compiler-2.3-2.3.1-sources.jar: org/neo4j/cypher/internal/compiler/v2_3/codegen/ir/MethodInvocation.scala <==
/*
 * Copyright (c) 2002-2015 "Neo Technology,"
 * Network Engine for Objects in Lund AB [http://neotechnology.com]
 *
 * This file is part of Neo4j.
 *
 * Neo4j is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation, either version 3 of the License, or
 * (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program.  If not, see <http://www.gnu.org/licenses/>.
 */
package org.neo4j.cypher.internal.compiler.v2_3.codegen.ir

import org.neo4j.cypher.internal.compiler.v2_3.codegen._

case class MethodInvocation(override val operatorId: Set[String],
                            symbol:JoinTableMethod,
                            methodName: String,
                            statements: Seq[Instruction]) extends Instruction {

  override def init[E](generator: MethodStructure[E])(implicit context: CodeGenContext) = {}

  override def body[E](generator: MethodStructure[E])(implicit context: CodeGenContext) = {
    generator.method(symbol.tableType, symbol.name, methodName) { body =>
      statements.foreach(_.init(body))
      statements.foreach(_.body(body))
    }
  }

  override def children = statements
}

==> neo4j-cypher-compiler-3.1-3.1.9-sources.jar: org/neo4j/cypher/internal/compiler/v3_1/codegen/ir/MethodInvocation.scala <==
/*
 * Copyright (c) 2002-2018 "Neo Technology,"
 * Network Engine for Objects in Lund AB [http://neotechnology.com]
 *
 * This file is part of Neo4j.
 *
 * Neo4j is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation, either version 3 of the License, or
 * (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program.  If not, see <http://www.gnu.org/licenses/>.
 */
package org.neo4j.cypher.internal.compiler.v3_1.codegen.ir

import org.neo4j.cypher.internal.compiler.v3_1.codegen._

case class MethodInvocation(override val operatorId: Set[String],
                            symbol:JoinTableMethod,
                            methodName: String,
                            statements: Seq[Instruction]) extends Instruction {

  override def init[E](generator: MethodStructure[E])(implicit context: CodeGenContext) = {}

  override def body[E](generator: MethodStructure[E])(implicit context: CodeGenContext) = {
    generator.invokeMethod(symbol.tableType, symbol.name, methodName) { body =>
      statements.foreach(_.init(body))
      statements.foreach(_.body(body))
    }
  }

  override def children = statements
}
